@@ -66,6 +66,7 @@ if TYPE_CHECKING:
 
 
 _logger = logging.getLogger(__name__)
+cache_dir_lock: None | FileLock = None
 
 
 class LintLogHandler(logging.Handler):
@@ -130,11 +131,12 @@ def initialize_options(arguments: list[str] | None = None) -> None:
     if options.cache_dir:
         options.cache_dir.mkdir(parents=True, exist_ok=True)
 
-    options.cache_dir_lock = None
     if not options.offline:  # pragma: no cover
-        options.cache_dir_lock = FileLock(f"{options.cache_dir}/.lock")
+        cache_dir_lock = FileLock(  # pylint: disable=redefined-outer-name
+            f"{options.cache_dir}/.lock",
+        )
         try:
-            options.cache_dir_lock.acquire(timeout=180)
+            cache_dir_lock.acquire(timeout=180)
         except Timeout:  # pragma: no cover
             _logger.error(
                 "Timeout waiting for another instance of ansible-lint to release the lock.",
@@ -192,7 +194,7 @@ def _do_transform(result: LintResult, opts: Options) -> None:
 
 def support_banner() -> None:
     """Display support banner when running on unsupported platform."""
-    if sys.version_info < (3, 9, 0):  # pragma: no cover
+    if sys.version_info < (3, 9, 0):  # pragma: no cover # noqa: UP036
         prefix = "::warning::" if "GITHUB_ACTION" in os.environ else "WARNING: "
         console_stderr.print(
             f"{prefix}ansible-lint is no longer tested under Python {sys.version_info.major}.{sys.version_info.minor} and will soon require 3.9. Do not report bugs for this version.",
@@ -244,18 +246,23 @@ def main(argv: list[str] | None = None) -> int:
     from ansiblelint.rules import RulesCollection
     from ansiblelint.runner import _get_matches
 
-    rules = RulesCollection(options.rulesdirs, profile_name=options.profile)
-
     if options.list_profiles:
         from ansiblelint.generate_docs import profiles_as_rich
 
         console.print(profiles_as_rich())
         return 0
 
+    app = get_app(offline=None)  # to be sure we use the offline value from settings
+    rules = RulesCollection(
+        options.rulesdirs,
+        profile_name=options.profile,
+        app=app,
+        options=options,
+    )
+
     if options.list_rules or options.list_tags:
         return _do_list(rules)
 
-    app = get_app()
     if isinstance(options.tags, str):
         options.tags = options.tags.split(",")  # pragma: no cover
     result = _get_matches(rules, options)
@@ -267,10 +274,20 @@ def main(argv: list[str] | None = None) -> int:
 
         if Version(ruamel_safe_version) > Version(ruamel_yaml_version_str):
             _logger.warning(
-                "We detected use of `--write` feature with a buggy ruamel-yaml %s library instead of >=%s, upgrade it before reporting any bugs like dropped comments.",
+                "We detected use of `--fix` feature with a buggy ruamel-yaml %s library instead of >=%s, upgrade it before reporting any bugs like dropped comments.",
                 ruamel_yaml_version_str,
                 ruamel_safe_version,
             )
+        acceptable_tags = {"all", "none", *rules.known_tags()}
+        unknown_tags = set(options.write_list).difference(acceptable_tags)
+
+        if unknown_tags:
+            _logger.error(
+                "Found invalid value(s) (%s) for --fix arguments, must be one of: %s",
+                ", ".join(unknown_tags),
+                ", ".join(acceptable_tags),
+            )
+            sys.exit(RC.INVALID_CONFIG)
         _do_transform(result, options)
 
     mark_as_success = True
@@ -288,10 +305,10 @@ def main(argv: list[str] | None = None) -> int:
 
     app.render_matches(result.matches)
 
-    _perform_mockings_cleanup()
-    if options.cache_dir_lock:
-        options.cache_dir_lock.release()
-        pathlib.Path(options.cache_dir_lock.lock_file).unlink(missing_ok=True)
+    _perform_mockings_cleanup(app.options)
+    if cache_dir_lock:
+        cache_dir_lock.release()
+        pathlib.Path(cache_dir_lock.lock_file).unlink(missing_ok=True)
     if options.mock_filters:
         _logger.warning(
             "The following filters were mocked during the run: %s",
@@ -343,6 +360,7 @@ def path_inject() -> None:
     inject_paths = []
 
     userbase_bin_path = Path(site.getuserbase()) / "bin"
+
     if (
         str(userbase_bin_path) not in paths
         and (userbase_bin_path / "bin" / "ansible").exists()
@@ -350,7 +368,12 @@ def path_inject() -> None:
         inject_paths.append(str(userbase_bin_path))
 
     py_path = Path(sys.executable).parent
-    if str(py_path) not in paths and (py_path / "ansible").exists():
+    pipx_path = os.environ.get("PIPX_HOME", "pipx")
+    if (
+        str(py_path) not in paths
+        and (py_path / "ansible").exists()
+        and pipx_path not in str(py_path)
+    ):
         inject_paths.append(str(py_path))
 
     if not os.environ.get("PYENV_VIRTUAL_ENV", None):
