@@ -4,9 +4,9 @@ from __future__ import annotations
 import logging
 import re
 import sys
-from collections import namedtuple
+from dataclasses import dataclass
 from pathlib import Path
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, NamedTuple
 
 import black
 import jinja2
@@ -15,14 +15,18 @@ from ansible.parsing.yaml.objects import AnsibleUnicode
 from jinja2.exceptions import TemplateSyntaxError
 
 from ansiblelint.constants import LINE_NUMBER_KEY
+from ansiblelint.errors import RuleMatchTransformMeta
 from ansiblelint.file_utils import Lintable
-from ansiblelint.rules import AnsibleLintRule
+from ansiblelint.rules import AnsibleLintRule, TransformMixin
 from ansiblelint.skip_utils import get_rule_skips_from_line
 from ansiblelint.text import has_jinja
 from ansiblelint.utils import parse_yaml_from_file, template
 from ansiblelint.yaml_utils import deannotate, nested_items_path
 
 if TYPE_CHECKING:
+    from ruamel.yaml.comments import CommentedMap, CommentedSeq
+
+    from ansiblelint.config import Options
     from ansiblelint.errors import MatchError
     from ansiblelint.utils import Task
 
@@ -30,7 +34,14 @@ if TYPE_CHECKING:
 _logger = logging.getLogger(__package__)
 KEYWORDS_WITH_IMPLICIT_TEMPLATE = ("changed_when", "failed_when", "until", "when")
 
-Token = namedtuple("Token", "lineno token_type value")
+
+class Token(NamedTuple):
+    """Token."""
+
+    lineno: int
+    token_type: str
+    value: str
+
 
 ignored_re = re.compile(
     "|".join(  # noqa: FLY002
@@ -53,7 +64,27 @@ ignored_re = re.compile(
 )
 
 
-class JinjaRule(AnsibleLintRule):
+@dataclass(frozen=True)
+class JinjaRuleTMetaSpacing(RuleMatchTransformMeta):
+    """JinjaRule transform metadata.
+
+    :param key: Key or index within the task
+    :param value: Value of the key
+    :param path: Path to the key
+    :param fixed: Value with spacing fixed
+    """
+
+    key: str | int
+    value: str | int
+    path: tuple[str | int, ...]
+    fixed: str
+
+    def __str__(self) -> str:
+        """Return string representation."""
+        return f"{self.key}={self.value} at {self.path} fixed to {self.fixed}"
+
+
+class JinjaRule(AnsibleLintRule, TransformMixin):
     """Rule that looks inside jinja2 templates."""
 
     id = "jinja"
@@ -79,8 +110,8 @@ class JinjaRule(AnsibleLintRule):
         """Generate error message."""
         return self._tag2msg[tag].format(value=value, reformatted=reformatted)
 
-    # pylint: disable=too-many-branches,too-many-locals
-    def matchtask(  # noqa: C901
+    # pylint: disable=too-many-locals
+    def matchtask(
         self,
         task: Task,
         file: Lintable | None = None,
@@ -94,7 +125,7 @@ class JinjaRule(AnsibleLintRule):
                 if isinstance(v, str):
                     try:
                         template(
-                            basedir=file.path.parent if file else Path("."),
+                            basedir=file.path.parent if file else Path(),
                             value=v,
                             variables=deannotate(task.get("vars", {})),
                             fail_on_error=True,  # we later decide which ones to ignore or not
@@ -166,6 +197,12 @@ class JinjaRule(AnsibleLintRule):
                                 details=details,
                                 filename=file,
                                 tag=f"{self.id}[{tag}]",
+                                transform_meta=JinjaRuleTMetaSpacing(
+                                    key=key,
+                                    value=v,
+                                    path=tuple(path),
+                                    fixed=reformatted,
+                                ),
                             ),
                         )
         except Exception as exc:
@@ -249,8 +286,8 @@ class JinjaRule(AnsibleLintRule):
             last_value = value
         return result
 
-    # pylint: disable=too-many-branches,too-many-statements,too-many-locals
-    def check_whitespace(  # noqa: C901
+    # pylint: disable=too-many-statements,too-many-locals
+    def check_whitespace(
         self,
         text: str,
         key: str,
@@ -370,6 +407,68 @@ class JinjaRule(AnsibleLintRule):
         )
         return reformatted, details, "spacing"
 
+    def transform(
+        self: JinjaRule,
+        match: MatchError,
+        lintable: Lintable,
+        data: CommentedMap | CommentedSeq | str,
+    ) -> None:
+        """Transform jinja2 errors.
+
+        :param match: MatchError instance
+        :param lintable: Lintable instance
+        :param data: data to transform
+        """
+        if match.tag == "jinja[spacing]":
+            self._transform_spacing(match, data)
+
+    def _transform_spacing(
+        self: JinjaRule,
+        match: MatchError,
+        data: CommentedMap | CommentedSeq | str,
+    ) -> None:
+        """Transform jinja2 spacing errors.
+
+        The match error was found on a normalized task so we cannot compare the path
+        instead we only compare the key and value, if the task has 2 identical keys with the
+        exact same jinja spacing issue, we may transform them out of order
+
+        :param match: MatchError instance
+        :param data: data to transform
+        """
+        if not isinstance(match.transform_meta, JinjaRuleTMetaSpacing):
+            return
+        if isinstance(data, str):
+            return
+
+        obj = self.seek(match.yaml_path, data)
+        if obj is None:
+            return
+
+        ignored_keys = ("block", "ansible.builtin.block", "ansible.legacy.block")
+        for key, value, path in nested_items_path(
+            data_collection=obj,
+            ignored_keys=ignored_keys,
+        ):
+            if key == match.transform_meta.key and value == match.transform_meta.value:
+                if not path:
+                    continue
+                for pth in path[:-1]:
+                    try:
+                        obj = obj[pth]
+                    except (KeyError, TypeError) as exc:
+                        err = f"Unable to transform {match.transform_meta}: {exc}"
+                        _logger.error(err)
+                        return
+                try:
+                    obj[path[-1]][key] = match.transform_meta.fixed
+                    match.fixed = True
+
+                except (KeyError, TypeError) as exc:
+                    err = f"Unable to transform {match.transform_meta}: {exc}"
+                    _logger.error(err)
+                return
+
 
 def blacken(text: str) -> str:
     """Format Jinja2 template using black."""
@@ -383,7 +482,13 @@ if "pytest" in sys.modules:
     import pytest
 
     from ansiblelint.rules import RulesCollection  # pylint: disable=ungrouped-imports
-    from ansiblelint.runner import Runner  # pylint: disable=ungrouped-imports
+    from ansiblelint.runner import (
+        Runner,
+        _get_matches,
+    )
+
+    # pylint: disable=ungrouped-imports
+    from ansiblelint.transformer import Transformer  # pylint: disable=ungrouped-imports
 
     @pytest.fixture(name="error_expected_lines")
     def fixture_error_expected_lines() -> list[int]:
@@ -725,6 +830,38 @@ if "pytest" in sys.modules:
         errs = Runner(success, rules=collection).run()
         assert len(errs) == 0
 
+    def test_jinja_transform(
+        config_options: Options,
+        copy_examples_dir: tuple[Path, Path],
+        default_rules_collection: RulesCollection,
+    ) -> None:
+        """Test transform functionality for jinja rule."""
+        playbook: str = "examples/playbooks/rule-jinja-before.yml"
+        config_options.write_list = ["all"]
+
+        config_options.lintables = [playbook]
+        runner_result = _get_matches(
+            rules=default_rules_collection,
+            options=config_options,
+        )
+        transformer = Transformer(result=runner_result, options=config_options)
+        transformer.run()
+
+        matches = runner_result.matches
+        assert len(matches) == 2
+
+        orig_dir, tmp_dir = copy_examples_dir
+        orig_playbook = orig_dir / playbook
+        expected_playbook = orig_dir / playbook.replace(".yml", ".transformed.yml")
+        transformed_playbook = tmp_dir / playbook
+
+        orig_playbook_content = orig_playbook.read_text()
+        expected_playbook_content = expected_playbook.read_text()
+        transformed_playbook_content = transformed_playbook.read_text()
+
+        assert orig_playbook_content != transformed_playbook_content
+        assert transformed_playbook_content == expected_playbook_content
+
 
 def _get_error_line(task: dict[str, Any], path: list[str | int]) -> int:
     """Return error line number."""
