@@ -1,40 +1,24 @@
 """Tests for Transformer."""
+from __future__ import annotations
 
-import os
-import pathlib
-import shutil
-from argparse import Namespace
-from typing import Iterator, List, Set, Tuple
+from typing import TYPE_CHECKING
 
 import pytest
 
-from ansiblelint.rules import RulesCollection
-
 # noinspection PyProtectedMember
 from ansiblelint.runner import LintResult, _get_matches
 from ansiblelint.transformer import Transformer
 
+if TYPE_CHECKING:
+    from pathlib import Path
 
-@pytest.fixture(name="copy_examples_dir")
-def fixture_copy_examples_dir(
-    tmp_path: pathlib.Path, config_options: Namespace
-) -> Iterator[Tuple[pathlib.Path, pathlib.Path]]:
-    """Fixture that copies the examples/ dir into a tmpdir."""
-    examples_dir = pathlib.Path("examples")
-
-    shutil.copytree(examples_dir, tmp_path / "examples")
-    old_cwd = os.getcwd()
-    try:
-        os.chdir(tmp_path)
-        config_options.cwd = tmp_path
-        yield pathlib.Path(old_cwd), tmp_path
-    finally:
-        os.chdir(old_cwd)
+    from ansiblelint.config import Options
+    from ansiblelint.rules import RulesCollection
 
 
 @pytest.fixture(name="runner_result")
 def fixture_runner_result(
-    config_options: Namespace,
+    config_options: Options,
     default_rules_collection: RulesCollection,
     playbook: str,
 ) -> LintResult:
@@ -49,36 +33,110 @@ def fixture_runner_result(
     (
         # reuse TestRunner::test_runner test cases to ensure transformer does not mangle matches
         pytest.param(
-            "examples/playbooks/nomatchestest.yml", 0, False, id="nomatchestest"
+            "examples/playbooks/nomatchestest.yml",
+            0,
+            False,
+            id="nomatchestest",
         ),
         pytest.param("examples/playbooks/unicode.yml", 1, False, id="unicode"),
         pytest.param(
-            "examples/playbooks/lots_of_warnings.yml", 992, False, id="lots_of_warnings"
+            "examples/playbooks/lots_of_warnings.yml",
+            993,
+            False,
+            id="lots_of_warnings",
         ),
         pytest.param("examples/playbooks/become.yml", 0, False, id="become"),
         pytest.param(
-            "examples/playbooks/contains_secrets.yml", 0, False, id="contains_secrets"
+            "examples/playbooks/contains_secrets.yml",
+            0,
+            False,
+            id="contains_secrets",
         ),
         pytest.param(
-            "examples/playbooks/vars/empty_vars.yml", 0, False, id="empty_vars"
+            "examples/playbooks/vars/empty_vars.yml",
+            0,
+            False,
+            id="empty_vars",
         ),
         pytest.param("examples/playbooks/vars/strings.yml", 0, True, id="strings"),
+        pytest.param("examples/playbooks/vars/empty.yml", 1, False, id="empty"),
+        pytest.param("examples/playbooks/name-case.yml", 1, True, id="name_case"),
+        pytest.param("examples/playbooks/fqcn.yml", 3, True, id="fqcn"),
+        pytest.param(
+            "examples/playbooks/multi_yaml_doc.yml",
+            1,
+            False,
+            id="multi_yaml_doc",
+        ),
+        pytest.param(
+            "examples/playbooks/transform_command_instead_of_shell.yml",
+            3,
+            True,
+            id="cmd_instead_of_shell",
+        ),
+        pytest.param(
+            "examples/playbooks/transform-deprecated-local-action.yml",
+            1,
+            True,
+            id="dep_local_action",
+        ),
+        pytest.param(
+            "examples/playbooks/transform-block-indentation-indicator.yml",
+            0,
+            True,
+            id="multiline_msg_with_indent_indicator",
+        ),
+        pytest.param(
+            "examples/playbooks/transform-jinja.yml",
+            7,
+            True,
+            id="jinja_spacing",
+        ),
+        pytest.param(
+            "examples/playbooks/transform-no-jinja-when.yml",
+            3,
+            True,
+            id="no_jinja_when",
+        ),
+        pytest.param(
+            "examples/playbooks/vars/transform_nested_data.yml",
+            3,
+            True,
+            id="nested",
+        ),
+        pytest.param(
+            "examples/playbooks/transform-key-order.yml",
+            6,
+            True,
+            id="key_order_transform",
+        ),
+        pytest.param(
+            "examples/playbooks/transform-no-free-form.yml",
+            2,
+            True,
+            id="no_free_form_transform",
+        ),
+        pytest.param(
+            "examples/playbooks/transform-partial-become.yml",
+            4,
+            True,
+            id="partial_become",
+        ),
     ),
 )
 def test_transformer(  # pylint: disable=too-many-arguments, too-many-locals
-    config_options: Namespace,
-    copy_examples_dir: Tuple[pathlib.Path, pathlib.Path],
+    config_options: Options,
+    copy_examples_dir: tuple[Path, Path],
     playbook: str,
     runner_result: LintResult,
     transformed: bool,
     matches_count: int,
 ) -> None:
-    """
-    Test that transformer can go through any corner cases.
+    """Test that transformer can go through any corner cases.
 
     Based on TestRunner::test_runner
     """
-    setattr(config_options, "write_list", ["all"])
+    config_options.write_list = ["all"]
     transformer = Transformer(result=runner_result, options=config_options)
     transformer.run()
 
@@ -149,7 +207,7 @@ def test_transformer(  # pylint: disable=too-many-arguments, too-many-locals
         (["rule-id", "rule-id", "rule-id"], {"rule-id"}),
     ),
 )
-def test_effective_write_set(write_list: List[str], expected: Set[str]) -> None:
+def test_effective_write_set(write_list: list[str], expected: set[str]) -> None:
     """Make sure effective_write_set handles all/none keywords correctly."""
     actual = Transformer.effective_write_set(write_list)
     assert actual == expected
